Maui.Input (maui v0.1.17)

Summary

Functions

checkbox(assigns)

Attributes

  • id (:any) - Defaults to nil.
  • label (:string) - Defaults to nil.
  • class (:string) - Defaults to nil.
  • field (Phoenix.HTML.FormField) - a form field struct retrieved from the form, for example: @form[:email]. Defaults to nil.
  • Global attributes are accepted. Supports all globals plus: ["accept", "autocomplete", "capture", "cols", "disabled", "form", "list", "max", "maxlength", "min", "minlength", "multiple", "pattern", "placeholder", "readonly", "required", "rows", "size", "step", "checked", "name", "value"].

Slots

  • inner_block

generate_id(prefix \\ "input")

input(assigns)

Attributes

  • id (:any) - Defaults to nil.
  • class (:string) - Defaults to "".
  • type (:string) - Defaults to "text".
  • label (:string) - Defaults to nil.
  • field (Phoenix.HTML.FormField) - a form field struct retrieved from the form, for example: @form[:email]. Defaults to nil.
  • Global attributes are accepted. Supports all globals plus: ["accept", "autocomplete", "capture", "cols", "disabled", "form", "list", "max", "maxlength", "min", "minlength", "multiple", "pattern", "placeholder", "readonly", "required", "rows", "size", "step", "name", "value"].

label(assigns)

Attributes

  • class (:string) - Defaults to "".
  • Global attributes are accepted. Supports all globals plus: ["for"].

Slots

  • inner_block

map_field(assigns)

radio(assigns)

Attributes

  • id (:any) - Defaults to nil.
  • class (:string) - Defaults to "".
  • field (Phoenix.HTML.FormField) - a form field struct retrieved from the form, for example: @form[:email]. Defaults to nil.
  • Global attributes are accepted. Supports all globals plus: ["checked", "name", "value"].

switch(assigns)

Attributes

  • id (:any) - Defaults to nil.
  • class (:string) - Defaults to "".
  • label (:string) - Defaults to nil.
  • field (Phoenix.HTML.FormField) - a form field struct retrieved from the form, for example: @form[:email]. Defaults to nil.
  • Global attributes are accepted. Supports all globals plus: ["accept", "capture", "cols", "disabled", "form", "list", "max", "maxlength", "min", "minlength", "multiple", "pattern", "placeholder", "readonly", "required", "rows", "size", "step", "name", "value"].

textarea(assigns)

Attributes

  • id (:any) - Defaults to nil.
  • class (:string) - Defaults to "".
  • label (:string) - Defaults to nil.
  • field (Phoenix.HTML.FormField) - a form field struct retrieved from the form, for example: @form[:email]. Defaults to nil.
  • Global attributes are accepted. Supports all globals plus: ["accept", "capture", "cols", "disabled", "form", "list", "max", "maxlength", "min", "minlength", "multiple", "pattern", "placeholder", "readonly", "required", "rows", "size", "step", "name", "value"].