Maui.Container (maui v0.1.17)
Summary
Functions
Attributes
class(:string) - Defaults to"".- Global attributes are accepted.
Slots
inner_block
Slots
inner_block
Slots
inner_block
Slots
inner_block
Slots
inner_block
Slots
inner_block
Renders a header with title.
Slots
inner_block(required)subtitleactions
ported from core components Renders a Heroicon.
Heroicons come in three styles – outline, solid, and mini.
By default, the outline style is used, but solid and mini may
be applied by using the -solid and -mini suffix.
You can customize the size and colors of the icons by setting width, height, and background color classes.
Icons are extracted from the deps/heroicons directory and bundled within
your compiled app.css by the plugin in assets/vendor/heroicons.js.
Examples
<.icon name="hero-x-mark" />
<.icon name="hero-arrow-path" class="ml-1 size-3 motion-safe:animate-spin" />Attributes
name(:string) (required)class(:string) - Defaults to"size-4".