Maui.Input
(maui v0.1.17)
Functions
Attributes
id (:any) - Defaults to nil.label (:string) - Defaults to nil.class (:string) - Defaults to nil.field (Phoenix.HTML.FormField) - a form field struct retrieved from the form, for example: @form[:email]. Defaults to nil.- Global attributes are accepted. Supports all globals plus:
["accept", "autocomplete", "capture", "cols", "disabled", "form", "list", "max", "maxlength", "min", "minlength", "multiple", "pattern", "placeholder", "readonly", "required", "rows", "size", "step", "checked", "name", "value"].
Slots
Attributes
class (:string) - Defaults to "".- Global attributes are accepted. Supports all globals plus:
["for"].
Slots
Attributes
id (:any) - Defaults to nil.class (:string) - Defaults to "".field (Phoenix.HTML.FormField) - a form field struct retrieved from the form, for example: @form[:email]. Defaults to nil.- Global attributes are accepted. Supports all globals plus:
["checked", "name", "value"].
Attributes
id (:any) - Defaults to nil.class (:string) - Defaults to "".label (:string) - Defaults to nil.field (Phoenix.HTML.FormField) - a form field struct retrieved from the form, for example: @form[:email]. Defaults to nil.- Global attributes are accepted. Supports all globals plus:
["accept", "capture", "cols", "disabled", "form", "list", "max", "maxlength", "min", "minlength", "multiple", "pattern", "placeholder", "readonly", "required", "rows", "size", "step", "name", "value"].
Attributes
id (:any) - Defaults to nil.class (:string) - Defaults to "".label (:string) - Defaults to nil.field (Phoenix.HTML.FormField) - a form field struct retrieved from the form, for example: @form[:email]. Defaults to nil.- Global attributes are accepted. Supports all globals plus:
["accept", "capture", "cols", "disabled", "form", "list", "max", "maxlength", "min", "minlength", "multiple", "pattern", "placeholder", "readonly", "required", "rows", "size", "step", "name", "value"].